@@ -24,7 +24,7 @@ module Yesod.Form.Types
 import Control.Monad.Trans.RWS (RWST)
 import Data.Text (Text)
 import Data.Monoid (Monoid (..))
-import Text.Blaze (Markup, ToMarkup (toMarkup))
+import Text.Blaze (Markup, ToMarkup (toMarkup), ToValue (toValue))
 #define Html Markup
 #define ToHtml ToMarkup
 #define toHtml toMarkup
@@ -51,28 +51,28 @@ instance Functor FormResult where
     fmap _ FormMissing = FormMissing
     fmap _ (FormFailure errs) = FormFailure errs
     fmap f (FormSuccess a) = FormSuccess $ f a
-instance Applicative FormResult where
+instance Control.Applicative.Applicative FormResult where
     pure = FormSuccess
     (FormSuccess f) <*> (FormSuccess g) = FormSuccess $ f g
     (FormFailure x) <*> (FormFailure y) = FormFailure $ x ++ y
     (FormFailure x) <*> _ = FormFailure x
     _ <*> (FormFailure y) = FormFailure y
     _ <*> _ = FormMissing
-instance Monoid m => Monoid (FormResult m) where
+instance Data.Monoid.Monoid m => Monoid (FormResult m) where
     mempty = pure mempty
     mappend x y = mappend <$> x <*> y
 instance Semigroup m => Semigroup (FormResult m) where
-    x <> y = (<>) <$> x <*> y
+    x <> y = (<>) Control.Applicative.<$> x <*> y
 
 -- | @since 1.4.5
-instance Foldable FormResult where
+instance Data.Foldable.Foldable FormResult where
     foldMap f r = case r of
       FormSuccess a -> f a
-      FormFailure errs -> mempty
+      FormFailure _errs -> mempty
       FormMissing -> mempty
 
 -- | @since 1.4.5
-instance Traversable FormResult where
+instance Data.Traversable.Traversable FormResult where
     traverse f r = case r of
       FormSuccess a -> fmap FormSuccess (f a)
       FormFailure errs -> pure (FormFailure errs)
@@ -85,6 +85,9 @@ data Enctype = UrlEncoded | Multipart
 instance ToHtml Enctype where
     toHtml UrlEncoded = "application/x-www-form-urlencoded"
     toHtml Multipart = "multipart/form-data"
+instance ToValue Enctype where
+    toValue UrlEncoded = "application/x-www-form-urlencoded"
+    toValue Multipart = "multipart/form-data"
 instance Monoid Enctype where
     mempty = UrlEncoded
     mappend UrlEncoded UrlEncoded = UrlEncoded
